@@ -3,4 +3,4 @@ pub mod server;
 
 pub type Result<T> = std::result::Result<T, Box<dyn std::error::Error + Send + Sync>>;
 
-pub const DEFAULT_GOPHERHOLE: &str = "gopher://phkt.io/";
+pub const DEFAULT_GOPHERHOLE: &str = "gopher://phroxy.net/";
